<?php
/**
 * Plugin Name: BillEase
 * Plugin URI: https://billease.ph
 * Description: Buy Now, Pay Later! with BillEase Installments
 * Version: 1.4.0
 * Author: First Digital Finance Corporation
 * Author URI: https://www.firstdigitalfinance.com
 * Text Domain: billease
 * Domain Path: /languages
 *
 * License: Apache-2.0
 * License URI: https://www.apache.org/licenses/LICENSE-2.0
 */
defined('ABSPATH') or die();

add_action('plugins_loaded', function() {
  require_once( plugin_dir_path(__FILE__) . 'includes/class-of-payment-method-base.php');

  class BillEase_Payment_Method extends OF_Payment_Method_Base {

    public function __construct() {
      parent::__construct(__FILE__);
    }

    public function setup_properties() {
      parent::setup_properties();
      $this->id = 'billease';

      $this->icon = plugins_url( 'billease-logo.svg', __FILE__ );

      $this->title              = __( '', 'billease' );
      $this->description        = __( 'Split your payments in 3 equal installments or configure terms up to 12 months using this payment method. You can instantly sign up or login at checkout to complete your purchase.', 'billease' );
      $this->method_title       = __( 'BillEase | Buy Now, Pay Later. No card required.', 'billease' );
      $this->method_description = __( 'Buy Now, Pay Later! with BillEase Installments', 'billease' );
    }

    public function process_order( $order ) {
      $transaction = parent::process_order( $order );

      // Additional line item for all the surcharges
      $items_total = 0.0;
      foreach ( $transaction['transaction_details']['items'] as $item ) {
        $items_total += $item['price'] * $item['quantity'];
      }

      if ( $order->get_total() - $items_total != 0 ) {
        $transaction['transaction_details']['items'][] = array(
          'item_id' => 'others',
          'name' => __('Shipping/Tax/Discount', 'billease'),
          'description' => __('Shipping plus taxes, minus any discounts', 'billease'),
          'variation_name' => 'Shipping, taxes and discounts',
          'quantity' => 1,
          'price' => $order->get_total() - $items_total,
          'amount' => $order->get_total() - $items_total,
        );
      }

      return $transaction;
    }
  }

  add_filter('woocommerce_payment_gateways', [BillEase_Payment_Method::class, 'register_payment_method']);
});

register_activation_hook(__FILE__, function() {
  set_transient("${__FILE__}_activated", true, 30);
});
