const initPaymentSettingsSection = () => {
  const $ = jQuery;

  const mainForm = $('#mainform');

  mainForm.on('submit', () => {
    mainForm.find('input, textarea').prop('disabled', false);
  });

  $('#payment_method-tabs').tabs({
    classes: {
      'ui-tabs': 'of-tabs',
      'ui-tabs-nav': 'of-tabs-nav',
      'ui-tabs-tab': 'of-tabs-tab',
      'ui-tabs-panel': 'of-tabs-panel'
    }
  });

  const inputs = $('#payment_method-tabs').find('input');
  const editButton = $('#of-payment-method-section .woocommerce-edit-button');
  const cancelButton = $('#of-payment-method-section .woocommerce-cancel-button');
  const saveButton = $('#of-payment-method-section .woocommerce-save-button');

  inputs.prop('disabled', true);
  cancelButton.hide();
  saveButton.hide();

  let originalValues = {};

  editButton.on('click', () => {
    inputs.each(function() {
      const input = $(this);
      originalValues[input.attr('name')] = input.val();
    });

    inputs.prop('disabled', false);
    editButton.hide();
    cancelButton.show();
    saveButton.show();
    return false;
  });

  cancelButton.on('click', () => {
    inputs.each(function() {
      const input = $(this);
      const name = input.attr('name');
      if (originalValues.hasOwnProperty(name)) {
        input.val(originalValues[name]);
      }
    });

    inputs.prop('disabled', true);
    editButton.show();
    cancelButton.hide();
    saveButton.hide();
    return false;
  });

  saveButton.on('click', () => {
    // mainForm.find('input').prop('disabled', false);
    mainForm.find('[name=save]').click();
    return false;
  });
};

const initPaymentGatewaySection = () => {
  const $ = jQuery;
  const mainForm = $('#mainform');

  mainForm.on('submit', () => {
    mainForm.find('input, textarea').prop('disabled', false);
  });

  $('#payment_gateway-tabs').tabs({
    classes: {
      'ui-tabs': 'of-tabs',
      'ui-tabs-nav': 'of-tabs-nav',
      'ui-tabs-tab': 'of-tabs-tab',
      'ui-tabs-panel': 'of-tabs-panel'
    }
  });

  const url = new URL(window.location);
  const name = url.searchParams.get('section');
  const gateway = $(`select#woocommerce_${name}_payment_gateway`);
  const inputs = $('#payment_gateway-tabs').find('input, textarea');
  const editButton = $('#of-payment-gateway-section .woocommerce-edit-button');
  const cancelButton = $('#of-payment-gateway-section .woocommerce-cancel-button');
  const saveButton = $('#of-payment-gateway-section .woocommerce-save-button');
  const pgTabs =  $('#payment_gateway-tabs li[role=tab]');

  let activePgTabText =  $('#payment_gateway-tabs li.ui-tabs-active.ui-state-active a').text().toLowerCase();
  let activeGateway = '';

  inputs.prop('disabled', true);
  cancelButton.hide();
  saveButton.hide();

  pgTabs.on('click', () => {
      activePgTabText =  $('#payment_gateway-tabs li.ui-tabs-active.ui-state-active a').text().toLowerCase();
      $(`#payment_gateway-tabs textarea[name^="woocommerce_${name}_${activeGateway}_${activePgTabText}"]`).prop('required', true);
      $(`#payment_gateway-tabs textarea:not([name^="woocommerce_${name}_${activeGateway}_${activePgTabText}"])`).prop('required', false);
  })

  gateway.on('change', (e) => {
    $(`#payment_gateway-tabs tr[data-field-key^=woocommerce_${name}_${e.target.value}]`).prop('hidden', false);
    $(`#payment_gateway-tabs textarea[name^="woocommerce_${name}_${e.target.value}_${activePgTabText}"]`).prop('required', true);
  
    $(`#payment_gateway-tabs tr:not([data-field-key^=woocommerce_${name}_${e.target.value}])`).prop('hidden', true);
    $(`#payment_gateway-tabs textarea:not([name^="woocommerce_${name}_${e.target.value}_${activePgTabText}"])`).prop('required', false);

    activeGateway =  e.target.value;
  });
  gateway.change();

  let originalValues = {};

  editButton.on('click', () => {
    inputs.each(function() {
      const input = $(this);
      originalValues[input.attr('name')] = input.val();
    });

    inputs.prop('disabled', false);
    editButton.hide();
    cancelButton.show();
    saveButton.show();
    return false;
  });

  cancelButton.on('click', () => {
    inputs.each(function() {
      const input = $(this);
      const name = input.attr('name');
      if (originalValues.hasOwnProperty(name)) {
        input.val(originalValues[name]);
      }
    });

    inputs.prop('disabled', true);
    editButton.show();
    cancelButton.hide();
    saveButton.hide();
    return false;
  });

  saveButton.on('click', () => {
    // mainForm.find('input').prop('disabled', false);
    mainForm.find('[name=save]').click();
    return false;
  });
};

document.addEventListener('DOMContentLoaded', () => {
  initPaymentSettingsSection();
  initPaymentGatewaySection();
});
