<?php
if (class_exists('OF_Payment_Gateway_Utils')) {
  return;
}

class OF_Payment_Gateway_Utils {

  static function generate_title_payment_gateway($payment_gateway, $env, $key){
    $pg_name = ucfirst($payment_gateway);
    $ucfirst_env = ucfirst($env);
    $prop_title = ucwords(str_replace("_"," ", $key));

    return "{$pg_name} {$ucfirst_env} {$prop_title}";
  }

  static function field_type($type){
    switch ( $type ) {
      case 'boolean':
        return 'checkbox';
      default:
        return 'textarea';
    }
  }

  static function field_default_value( $field ) {
    if ( !isset( $field[ 'default' ] ) ) {
      return null;
    }

    if ( $field[ 'type' ] == 'boolean' ) {
      return $field[ 'default' ] ? 'yes' : 'no';
    }

    return $field[ 'default' ];
  }

  static function add_payment_gateway_settings(&$settings, $name, $config) {
    $groups = ['additional_params', 'credentials', 'charge_config'];
    foreach ( $groups as $group ) {
      if ( !isset( $config[ 'properties' ] ) || !isset( $config[ 'properties' ][ $group ] ) ) {
        continue;
      }
      self::add_payment_gateway_fields(
        $settings, $name, $config[ 'properties' ][ $group ]
      );
    }
  }

  static function add_payment_gateway_fields(&$settings, $name, $fields) {
    foreach ( ALL_ENVS as $env ) {
      foreach ( $fields[ 'properties' ] as $field_name => $field_spec ) {
        $settings[ "{$name}_{$env}_{$field_name}" ] = [
          'title' => __(
            self::generate_title_payment_gateway( $name, $env, $field_name ),
            'openfabric'
          ),
          'description' => __(
            self::generate_title_payment_gateway( $name, $env, $field_name ),
            'openfabric'
          ),
          'type' => self::field_type( $field_spec[ 'type' ] ),
          'payment_gateway' => $name,
          'section' => 'payment_gateway',
          'default' => self::field_default_value( $field_spec ),
          'tab' => $env == LIVE_ENV
        ];
      }
    }
  }

  static function get_pg_config( $settings, $pg_name, $pg_config, $env ) {
    $config = [];

    $groups = ['additional_params', 'credentials', 'charge_config'];
    foreach ( $groups as $group ) {
      if ( !isset($pg_config[ 'properties' ][ $group ]) ) {
        continue;
      }

      $config[ $group ] = [];
      foreach ( $pg_config[ 'properties' ][ $group ][ 'properties' ] as $field_name => $field_spec) {
        $config[ $group ][ $field_name ] = self::field_value(
          $settings[ "{$pg_name}_{$env}_{$field_name}" ],
          $field_spec
        );
      }
    }

    $config['credential_format'] = 'api_key_pair';
    $config['credentials'] = [
      'api_key_pair' => $config['credentials']
    ];

    return $config;
  }

  static function field_value( $value, $spec ) {
    if ( !isset( $spec[ 'type' ] ) ) {
      return html_entity_decode($value);
    }

    if ( $spec[ 'type' ] == 'boolean' ) {
      return $value == 'yes';
    }

    return html_entity_decode($value);
  }
}
