<?php
if (class_exists('OF_Public_API')) {
  return;
}

require_once(plugin_dir_path(__FILE__) . 'class-of-helpers.php');
require_once(plugin_dir_path(__FILE__) . 'class-of-http-utils.php');

class OF_Public_API {
  private $endpoint;
  private $decorators;
  private $cache_key = 'PG_CONFIGURATION';

  public function __construct($endpoint, $decorators) {
    $this->endpoint = $endpoint;
    $this->decorators = $decorators;
  }

  public function get_pg_configuration_metadata(){
    $data = get_transient( $this->cache_key );
    if ( $data ) {
      return $data;
    }

    try {
      $url = "{$this->endpoint}/v1/pg_configuration_metadata";

      $response = wp_remote_get($url, OF_Helpers::apply_decorators(array(
        'headers' => array(
          'Content-Type' => 'application/json',
        ),
        'timeout' => 60,
      ), $this->decorators));

      $data = OF_Http_Utils::get_response_body($response);

      set_transient( $this->cache_key, $data, 86400 ); // 1 day

      return $data;
    } catch (Exception $e){
      delete_transient($this->cache_key);
      throw new WP_Error('error', $e->getMessage());
    }
  }
}
